.. _install:

Install and configure the Bare Metal service
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This section describes how to install and configure the
Bare Metal service, code-named ironic.

Note that installation and configuration vary by distribution.

.. toctree::
   :maxdepth: 2

   install-rdo.rst
   install-ubuntu.rst
   install-obs.rst
